.. dowhy documentation master file, created by
   sphinx-quickstart on Tue Mar 13 14:48:10 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


.. include:: ../../README.rst

.. toctree::
   :maxdepth: 4
   :caption: Contents:
   
   readme
   example_notebooks/nb_index
   code_repo
   dowhy

   


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
